@@ -4,12 +4,12 @@ from __future__ import annotations
 __all__ = ["Vector", "angle"]
 
 import cmath
-from collections.abc import Iterable
+from collections.abc import Generator, Iterable
 from dataclasses import dataclass
-from typing import Optional, SupportsIndex, Union
+from typing import Optional, SupportsIndex, Union, overload
 
 
-def angle(angle: float, /, unit: str):
+def angle(angle: float, /, unit: str) -> float:
     """Convert an angle to radians."""
     unit = unit.lower()
     if unit in {"d", "deg", "degrees", "degree", "°"}:
@@ -52,7 +52,7 @@ class Vector:
     _complex: complex
 
     def __init__(
-        self, x: Union[complex, float, Iterable[float]], y: Optional[float] = None
+        self, /, x: Union[complex, float, Iterable[float]], y: Optional[float] = None
     ):
         """Create a Vector from a single argument or x, y pair."""
         if y is None:
@@ -68,10 +68,8 @@ class Vector:
                 raise TypeError("x and y values must be numeric to create Vector")
 
     @staticmethod
-    def from_polar(r: float, theta: float):
+    def from_polar(r: float, theta: float) -> Vector:
         """Create a Vector from polar coordinates."""
-        if r == 0:
-            return Vector(0, 0)
         return Vector(cmath.rect(r, theta))
 
     def dot(self, other: Vector, /) -> float:
@@ -101,19 +99,21 @@ class Vector:
         This is one of the 'cross products' that can be defined on 2D
         vectors. Use -Vector.perp() for a clockwise rotation.
         """
-        return Vector(complex(-self._complex.imag, self._complex.real))
+        return Vector(self._complex * 1j)
 
-    def rotate(self, angle: float) -> Vector:
+    def rotate(self, /, angle: float) -> Vector:
         """
         Return a self, rotated by angle anticlockwise.
 
         Use negative angles for a clockwise rotation.
         """
-        return Vector(cmath.rect(self.r, self.theta + angle))
+        return Vector(
+            cmath.rect(abs(self._complex), cmath.phase(self._complex) + angle)
+        )
 
     def hat(self, /) -> Vector:
         """Return a Vector with the same direction, but unit length."""
-        return self / abs(self)
+        return Vector(self._complex / abs(self._complex))
 
     def rec(self, /) -> tuple[float, float]:
         """Get the vector as (x, y)."""
@@ -123,33 +123,49 @@ class Vector:
         """Get the vector as (r, theta)."""
         return cmath.polar(self._complex)
 
-    def round(self, ndigits: int = 0, /) -> tuple:
+    @overload
+    def round(self, /, ndigits: None = ...) -> tuple[int, int]:
+        ...
+
+    @overload
+    def round(self, /, ndigits: int) -> tuple[float, float]:
+        ...
+
+    def round(self, /, ndigits=None):
         """Get the vector with both components rounded, as a tuple."""
         return (round(self._complex.real, ndigits), round(self._complex.imag, ndigits))
 
-    def __str__(self, /):
+    def __str__(self, /) -> str:
         return f"({self._complex.real} {self._complex.imag})"
 
-    def __repr__(self, /):
+    def __repr__(self, /) -> str:
         return (
             f"{self.__class__.__qualname__}({self._complex.real}, {self._complex.imag})"
         )
 
-    def __len__(self, /):
+    def __len__(self, /) -> int:
         return 2
 
+    @overload
+    def __getitem__(self, key: slice, /) -> tuple[float, ...]:
+        ...
+
+    @overload
     def __getitem__(self, key: SupportsIndex, /) -> float:
+        ...
+
+    def __getitem__(self, key, /):
         return self.rec()[key]
 
-    def __iter__(self, /):
+    def __iter__(self, /) -> Generator[float, None, None]:
         yield self._complex.real
         yield self._complex.imag
 
-    def __reversed__(self, /):
+    def __reversed__(self, /) -> Generator[float, None, None]:
         yield self._complex.imag
         yield self._complex.real
 
-    def __neg__(self, /):
+    def __neg__(self, /) -> Vector:
         return Vector(-self._complex)
 
     def __add__(self, other: Vector, /) -> Vector:
@@ -182,7 +198,7 @@ class Vector:
     @property
     def r(self) -> float:
         """The radius of the vector."""
-        return abs(self)
+        return abs(self._complex)
 
     @property
     def theta(self) -> float:
